Chapter 4: Inversions
=====================

In chapter 4, we use *Inversions* to reconstruct complex source galaxies on pixelized grids.

The chapter contains the following tutorials:

`Tutorial 1: Pixelizations <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_1_pixelizations.html>`_
- Creating a pixel-grid in the source-plane.

`Tutorial 2: Mappers <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_2_mappers.html>`_
- How a pixelizations maps source-pixels to image-pixels.

`Tutorial 3: Inversions <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_3_inversions.html>`_
- Inverting the mappings to reconstruct the source's light.

`Tutorial 4: Bayesian Regularization <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_4_bayesian_regularization.html>`_
- Smoothing the source within a Bayesian framework.

`Tutorial 5: Borders <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_5_borders.html>`_
-Preventing highly demagnified image-pixels ruining the inversion.

`Tutorial 6: Lens Modeling  <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_6_lens_modeling.html>`_
- How to use inversions to fit a lens model.

`Tutorial 7: Adaptive Pixelization <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_7_adaptive_pixelization.html>`_
- An Voronoi pixelization which adapts to the mass model's magnification.

`Tutorial 8: Pipeline Inversion <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_4_inversions/tutorial_8_pipeline_runner.html>`_
- An example pipeline which uses an inversion.

.. toctree::
   :caption: Tutorials:
   :maxdepth: 1
   :hidden:

   tutorial_1_pixelizations
   tutorial_2_mappers
   tutorial_3_inversions
   tutorial_4_bayesian_regularization
   tutorial_5_borders
   tutorial_6_lens_modeling
   tutorial_7_adaptive_pixelization
   tutorial_8_pipeline_runner